============
Installation
============

Add 'anonymizer' to your ``INSTALLED_APPS`` setting. It would be advisable to
arrange it so that this only happens on development machines, and not anywhere
with access to the live database.


